import QtQuick 1.0

Rectangle {
    id: root

    property alias top_cat : top_cat_text.text
    property alias bottom_cat : bottom_cat_text.text
    property bool has_prev_screen : false

    width: parent.width
    height: bg_image.sourceSize.height

    signal goBack()
    signal goReload()
    signal goCategorySwitch()

    property url bg_image_source : screen.width > screen.height ? "gfx/header/header-bg_no_logo-landscape.png" : "gfx/header/header-bg_no_logo.png"

    Image {
        id: bg_image
        source: root.bg_image_source
        width: parent.width
    }        

    PushButton {
        id: go_back_button
        anchors.verticalCenter: parent.verticalCenter
        anchors.left: parent.left
        normal_image: has_prev_screen ? "gfx/header/header-button_back.png" : "gfx/exit_button/header-button_exit.png"
        pressed_image: has_prev_screen ? "gfx/header/header-button_back-clicked.png" : "gfx/exit_button/header-button_exit-clicked.png"
        onClicked: { root.goBack() }
    }

    Image {
        id: logo_image
        source: "gfx/header/header-logo.png"
        anchors.left: go_back_button.right
        anchors.leftMargin: 20
        anchors.rightMargin: 10
    }

    PushButton {
        id: reload_button
        anchors.verticalCenter: parent.verticalCenter
        anchors.right: parent.right
        normal_image: "gfx/header/header-button_reload.png"
        pressed_image: "gfx/header/header-button_reload-clicked.png"
        onClicked: { root.goReload() }
    }

    Item {
        id: menu
        anchors.top: parent.top
        anchors.rightMargin: 10
        anchors.left: logo_image.right
        anchors.right: reload_button.left
        anchors.bottom: parent.bottom

        Rectangle {
            id: splitter_rect
            anchors.verticalCenter: menu.verticalCenter
            anchors.left: parent.left
            anchors.right: parent.right
            height: 1
            color: "white"
            opacity: 0.5
        }

        Text {
            id: top_cat_text
            font.pixelSize: 15
            color: "white"
            horizontalAlignment: Text.AlignHCenter
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: splitter_rect.top
            elide: Text.ElideRight
            textFormat: Text.PlainText
            font.weight: Font.DemiBold
        }

        Image {
            id: down_arrow_image
            source: "gfx/header/header-arrow.png"
            anchors.right: parent.right
            anchors.top: splitter_rect.bottom
            anchors.topMargin: 6
        }

        Text {
            id: bottom_cat_text
            font.pixelSize: 15
            color: "white"
            horizontalAlignment: Text.AlignHCenter
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: splitter_rect.bottom
            elide: Text.ElideRight
            textFormat: Text.PlainText
        }

        states: [
            State {
                name: "PRESSED"
                PropertyChanges {
                    target: menu
                    opacity: 0.5
                }
            }
        ]

        transitions: [
            Transition {
                from: "*"
                to: "*"
                NumberAnimation { target: menu; property: "opacity"; duration: 100 }
            }
        ]

        MouseArea {
            anchors.fill: parent

            onClicked: {
                root.goCategorySwitch()
            }

            onPressed: {
                menu.state = "PRESSED"
            }

            onReleased: {
                menu.state = ""
            }

            onCanceled: {
                menu.state = ""
            }
        }
    }
}
