import QtQuick 1.0
import com.psiloc 1.1
import "AppView.js" as App

Rectangle {
    id: app_root
    color: "white"
    anchors.fill: parent

    property alias page_stack: stack
    property bool showHeader : true
    property bool showFooter : true

    signal informationViewLoaded()

    function appStartupComplete()
    {
        informationViewLoaded();
    }

    function goBack()
    {        
        if(!page_stack.currentPage)
        {
            Qt.quit();
        } else {
            var prevPage = page_stack.pop();
            if(!prevPage)
            {
                exit_dialog.open()
            }
        }
    }

    function playVideo(url)
    {
        if(native_utils.canOpenVideosInSystemPlayer())
        {
            native_utils.openVideoInSystemPlayer(url)
        } else {
            App.openVideoPlayer(url)
        }
    }

    ExitDialog {
        id: exit_dialog
    }

    AppHeader {
        id: app_header
        top_cat: ""
        bottom_cat: ""
        state: app_root.showHeader ? "Visible" : "Hidden"
        has_prev_screen: page_stack.depth > 1
        onGoBack: {
            app_root.goBack()
        }
        states: [
            State {
                name: "Visible"
                PropertyChanges { target: app_header; y: 0; opacity: 1 }
            },
            State {
                name: "Hidden"
                PropertyChanges { target: app_header; y: -height; opacity: 0 }
            }
        ]
        transitions: [
            Transition {
                from: "Hidden"; to: "Visible"
                ParallelAnimation {
                    NumberAnimation { target: app_header; properties: "y"; duration: 200; easing.type: Easing.OutQuad }
                    NumberAnimation { target: app_header; properties: "opacity"; duration: 200; easing.type: Easing.Linear }
                }
            },
            Transition {
                from: "Visible"; to: "Hidden"
                ParallelAnimation {
                    NumberAnimation { target: app_header; properties: "y"; duration: 200; easing.type: Easing.Linear }
                    NumberAnimation { target: app_header; properties: "opacity"; duration: 200; easing.type: Easing.Linear }
                }
            }
        ]
    }

    AppFooter {
        id: app_footer
        width: parent.width
        state: app_root.showFooter ? "Visible" : "Hidden"
        states: [
            State {
                name: "Visible"
                PropertyChanges { target: app_footer; y: parent.height - height; opacity: 1 }
            },
            State {
                name: "Hidden"
                PropertyChanges { target: app_footer; y: parent.height; opacity: 0 }
            }
        ]

        transitions: [
            Transition {
                from: "Hidden"; to: "Visible"
                ParallelAnimation {
                    NumberAnimation { target: app_footer; properties: "y"; duration: 200; easing.type: Easing.OutQuad }
                    NumberAnimation { target: app_footer; properties: "opacity"; duration: 200; easing.type: Easing.Linear }
                }
            },
            Transition {
                from: "Visible"; to: "Hidden"
                ParallelAnimation {
                    NumberAnimation { target: app_footer; properties: "y"; duration: 200; easing.type: Easing.Linear }
                    NumberAnimation { target: app_footer; properties: "opacity"; duration: 200; easing.type: Easing.Linear }
                }
            }
        ]
        onPageItemClicked: {
            App.openFooterItem(activeIndex)
        }
    }

    Item {
        anchors.top: app_header.bottom
        anchors.bottom: app_footer.top
        anchors.left: parent.left
        anchors.right: parent.right
        Item {
            id: contentItem
            anchors.fill: parent
            PageStack {
                id: stack
                anchors.fill: parent
            }
        }
    }

    WaitDialog {
        id: wait_dialog
    }

    MouseArea {
        anchors.fill: parent
        enabled: page_stack.busy
    }

    InfoDialog {
        id: info_dialog
    }

    Component.onCompleted: {
        App.openInformationView()
    }    
}
