import QtQuick 1.0
import "UIConstants.js" as UI
import com.psiloc 1.1

Image {
    id: root
    visible: false

    property alias model : list.model
    property Item visualParent : null

    signal categoryClicked(int category)

    Popup {
        id: popup
        objectName: "OptionsMenu"
        y: (app_root.height - popup.height) / 2
        animationDuration: 100
        state: "Hidden"
        visible: status != DialogStatus.Closed
        enabled: status == DialogStatus.Open
        width: app_root.width
        height: menu.height
        clip: true

        onFaderClicked: {
            root.close()
        }

        Item {
            id: menu
            width: menu_top_image.sourceSize.width
            height: app_root.height * 0.7
            anchors.horizontalCenter: parent.horizontalCenter

            Image {
                id: menu_top_image
                source: "gfx/menu/categories-popup-bg_top.png"
                width: parent.width
                anchors.top: parent.top
            }

            Image {
                id: menu_bottom_image
                source: "gfx/menu/categories-popup-bg_bottom.png"
                width: parent.width
                anchors.bottom: parent.bottom
            }

            Image {
                id: menu_middle_image
                source: "gfx/menu/categories-popup-bg_middle.png"
                anchors.left: menu_top_image.left
                anchors.right: menu_top_image.right
                anchors.top: menu_top_image.bottom
                anchors.bottom: menu_bottom_image.top
            }

            ListView {
                id: list
                anchors.left: menu_top_image.left
                anchors.right: menu_top_image.right
                anchors.top: menu_top_image.bottom
                anchors.bottom: menu_bottom_image.top
                anchors.leftMargin: (25 * menu_top_image.width) / 322
                anchors.rightMargin: (25 * menu_top_image.width) / 322
                clip: true                

                delegate: Item {
                    width: list.width
                    height: sel_image.sourceSize.height

                    Image {
                        id: sel_image
                        source: "gfx/menu/categories-item_selected-bg.png"
                        visible: list.currentIndex == index
                        anchors.fill: parent
                    }

                    Image {
                        id: div_image
                        source: "gfx/menu/categories-item_divider.png"
                        anchors.top: parent.top
                        anchors.left: parent.left
                        anchors.right: parent.right
                    }

                    Text {
                        text: name
                        font.pixelSize: 19
                        font.bold: bold
                        color: bold ? "blue" : "#3ba5cf"
                        elide: Text.ElideRight
                        anchors.fill: parent
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                    }

                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
//                            console.log("Clicked menu cat " + cat_value + "index =" + index)
                            list.currentIndex = index
                            root.close()
                            root.categoryClicked(cat_value)
                        }
                    }
                }
            }
        }

        states: [
            State {
                name: "Hidden"
                when: status == DialogStatus.Closing || status == DialogStatus.Closed
                PropertyChanges { target: menu; y: menu.height + 5; opacity: 0 }
            },
            State {
                name: "Visible"
                when: status == DialogStatus.Opening || status == DialogStatus.Open
                PropertyChanges { target: menu; y: 0; opacity: 1 }
            }
        ]

        transitions: [
            Transition {
                from: "Visible"; to: "Hidden"
                SequentialAnimation {
                    ParallelAnimation {
                        NumberAnimation {
                            target: menu
                            property: "y"
                            duration: popup.animationDuration
                            easing.type: Easing.Linear
                        }
                        NumberAnimation {
                            target: menu
                            property: "opacity"
                            duration: popup.animationDuration
                            easing.type: Easing.Linear
                        }
                    }
                    PropertyAction { target: popup; property: "status"; value: DialogStatus.Closed }
                }
            },
            Transition {
                from: "Hidden"; to: "Visible"
                SequentialAnimation {
                    ParallelAnimation {
                        NumberAnimation {
                            target: menu
                            property: "y"
                            duration: popup.animationDuration
                            easing.type: Easing.OutQuad
                        }
                        NumberAnimation {
                            target: menu
                            property: "opacity"
                            duration: popup.animationDuration
                            easing.type: Easing.Linear
                        }
                    }
                    PropertyAction { target: popup; property: "status"; value: DialogStatus.Open }
                }
            }
        ]
    }

    function open(selIndex)
    {
        console.log("Open drop down menu")

        for(var i = 0 ; i < model.count ; ++i)
        {
            console.log("Name = " + model.get(i).name + " Value = " + model.get(i).cat_value)
        }

        for(var i = 0 ; i < model.count ; ++i)
        {
            var item = model.get(i)
            if(item.cat_value == selIndex)
            {
                list.currentIndex = i
                list.positionViewAtIndex(i, ListView.Contain);
                break;
            }
        }
        popup.open()
    }

    function close()
    {
        popup.close()
    }
}
