import QtQuick 1.0
import com.psiloc 1.1

Page {
    id: root

    property int category : FotoCategoryModel.Nowe
    property string top_category : "FOTO"
    property string bottom_category : the_model.categoryName(category)
    property int tab_index : 2
    orientationLock: PageOrientation.LockPortrait

    signal openGallery(int oid, int category)

    Image {
        source: "gfx/video/video-bg.png"
        anchors.fill: parent
   }

    FotoCategoryViewDropDownMenu {
        id: drop_menu
        onCategoryClicked: {
            console.log("Category clicked " + category)
            if(category != root.category)
            {
                root.category = category
            }
        }
    }

    onReloadClicked: {
        the_model.reload()
    }

    onMenuClicked: {
        drop_menu.open(root.category)
    }

    ListView {
        id: lv
        anchors.fill: parent
        cacheBuffer: height
        model: FotoCategoryModel {
            category: root.category
            id: the_model
        }
        delegate: Item {
            width: lv.width
            height: 10 + gal_image.height + gal_text.height + splitter.height + 20

            id: img_item_id
            property int image_oid : oid

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    root.openGallery(oid, root.category)
                }
            }

            Text {
                id: gal_text
                text: tytul
                font.pixelSize: 15
                color: "white"
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.top: gal_image.bottom
                anchors.leftMargin: 10
                anchors.rightMargin: 10
                anchors.topMargin: 5
                wrapMode: Text.WordWrap
            }

            Row {
                id: gal_image
                spacing: (img_item_id.width - (3 * 104)) / 4
                x: spacing
                y: 10

                Repeater {
                    model: FotoGalleryModel {
                        oid: img_item_id.image_oid
                        category: the_model.category
                        limitResults: 3
                        itemsPerPage: 3
                    }

                    SmartImage {
                        width: 104
                        height: 104
                        source: img
                    }
                }
            }

            Image {
                id: splitter
                source: "gfx/foto/foto-item_divider.png"
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: parent.bottom
            }
        }
    }

    ScrollBar {
        id: scroll_bar
        anchors { right: parent.right; top: parent.top; bottom: parent.bottom; }
        width: 8
        scrollArea: lv
    }

    WaitBar {
        anchors.bottom: lv.bottom
        anchors.left: lv.left
        anchors.right: lv.right
        on: the_model.status == FotoCategoryModel.Loading
    }
}
