import QtQuick 1.0
import com.psiloc 1.1

Page {
    id: root

    property int category : -1
    property int oid : -1
    property int current_index : bottom_image_list.currentIndex + 1
    property string category_name : gallery_model.categoryName(category)
    orientationLock: PageOrientation.LockPortrait

    signal changeMainCategory(int category)

    tab_index : 2
    header_visible: false
    footer_visible: false

    onStatusChanged: {
        if(status == PageStatus.Deactivating) {
            zoomed_image_container.opacity = 0
            root.oid = -1
            root.category = -1
        }
    }

    FotoCategoryViewDropDownMenu {
        id: drop_menu
        onCategoryClicked: {
            root.changeMainCategory(category)
        }
    }

    Image {
        source: "gfx/foto/foto-bg.png"
        anchors.fill: parent
    }

    FotoGalleryModel {
        id: gallery_model
        category: root.category
        oid: root.oid
        selectedIndex: root.current_index - 1
    }

    function open(oid, category)
    {
        console.log("OId = " + oid + " Category = " + category)
        root.oid = oid
        root.category = category
//        bottom_image_list.positionViewAtBeginning()
        bottom_image_list.currentIndex = 0
    }

    Image {
        id: bottom_switcher
        source: "gfx/footer/footer-inactive_bg.png"
        width: root.width
        y: parent.height - height

        PushButton {
            id: left_arrow
            normal_image: "gfx/foto/foto-footer-arrow_left.png"
            pressed_image: "gfx/foto/foto-footer-arrow_left-clicked.png"
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            width: source_size.height * 2
            onClicked: {
                bottom_image_list.decrementCurrentIndex()
            }
        }

        Image {
            id: left_separator
            source: "gfx/footer/footer-divider.png"
            anchors.left: left_arrow.right
            anchors.top: parent.top
        }

        Text {
            anchors.left: left_separator.right
            anchors.right: right_separator.left
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            text: gallery_model.status == CategoryBasedModel.Ready ? root.current_index + " z " + gallery_model.count : "Ładowanie ..."
            color: "white"
            font.pixelSize: 30
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
        }

        Image {
            id: right_separator
            source: "gfx/footer/footer-divider.png"
            anchors.right: right_arrow.left
            anchors.top: parent.top
        }

        PushButton {
            id: right_arrow
            normal_image: "gfx/foto/foto-footer-arrow_right.png"
            pressed_image: "gfx/foto/foto-footer-arrow_right-clicked.png"
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: parent.right
            width: source_size.height * 2
            onClicked: {
                bottom_image_list.incrementCurrentIndex()
            }
        }
    }

    Rectangle {
        id: top_menu
        width: parent.width
        height: menu_go_back.height + 6

        color: "black"
        opacity: 0.4

        PushButton {
            id: menu_go_back
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            normal_image: "gfx/header/header-button_back.png"
            pressed_image: "gfx/header/header-button_back-clicked.png"
            onClicked: { app_root.goBack() }
        }

        Image {
            id: left_separator_menu
            source: "gfx/footer/footer-divider.png"
            anchors.left: menu_go_back.right
            anchors.top: parent.top
        }

        Text {
            id: category_menu_text
            text: root.category_name
            color: "white"
            anchors.left: left_separator_menu.right
            anchors.right: menu_pop_image.left
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            font.pixelSize: 30
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
        }

        Image {
            id: menu_pop_image
            source: "gfx/header/header-arrow.png"
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: right_separator_menu.right
            anchors.leftMargin: 5
            anchors.rightMargin: 5
        }

        MouseArea {
            anchors.left: category_menu_text.left
            anchors.right: right_separator_menu.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            onClicked: {
                drop_menu.open(root.category)
            }
        }

        Image {
            id: right_separator_menu
            source: "gfx/footer/footer-divider.png"
            anchors.right: menu_send_email.left
            anchors.top: parent.top
        }

        PushButton {
            id: menu_send_email
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: parent.right
            normal_image: "gfx/video/video-button_send.png"
            pressed_image: "gfx/video/video-button_send-clicked.png"
            onClicked: {
                formatEmail(gallery_model.currentTitle,
                            gallery_model.currentDescr,
                            gallery_model.currentImage)
            }
        }
    }

    Item {
        id: image_detail_view
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: top_menu.bottom
        anchors.bottom: bottom_image_spliiter.top
        anchors.bottomMargin: 10
        anchors.topMargin: 5
        clip: true

        property url this_image_url : gallery_model.currentImage

        Text {
            id: details_title
            font.pixelSize: 18
            color: "white"
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: parent.top
            wrapMode: Text.WordWrap
            text: gallery_model.currentTitle
        }

        Text {
            id: deltails_details
            font.pixelSize: 16
            color: "white"
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.top: details_title.bottom
            wrapMode: Text.WordWrap
            text: gallery_model.currentDescr
            textFormat: Text.RichText
        }

        SmartImage {
            id: larger_image_id
            source: image_detail_view.this_image_url
            anchors.top: deltails_details.bottom
            width: parent.width
            height: parent.height - deltails_details.y - deltails_details.height - 10

            PushButton {
                id: zoom_in_button
                normal_image: "gfx/foto/foto-button_enlarge.png"
                pressed_image: "gfx/foto/foto-button_enlarge-clicked.png"
                onClicked: {
                    zoomed_image_container.opacity = 1
                }
                x: parent.imageX + 10
                y: parent.imageY + 10
                visible: parent.status == Image.Ready
            }
        }
    }

    Image {
        id: bottom_image_spliiter
        source: "gfx/foto/foto-details_divider.png"
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: bottom_image_list.top
    }

    ListView {
        id: bottom_image_list
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: bottom_switcher.top
        height: (parent.height * 127) / 640
        model: gallery_model
        cacheBuffer: width
        delegate: Item {
            width: 120
            height: bottom_image_list.height

            SmartImage {
                id: inner_image
                source: img
                width: 104
                height: 104
                anchors.centerIn: parent
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    bottom_image_list.currentIndex = index
                }
            }
        }

        orientation: ListView.Horizontal
        spacing: 10
        boundsBehavior: Flickable.StopAtBounds
        highlightFollowsCurrentItem: false
        highlight: Image {
            source: "gfx/foto/foto-item_selected-bg.png"
            y: bottom_image_list.currentItem.y + (bottom_image_list.height - 104) / 2 - 3
            x: bottom_image_list.currentItem.x + 8 - 3
            width: 104 + 6
            height: 104 + 6
            Behavior on x {
                SpringAnimation {
                    spring: 3
                    damping: 0.2
                }
            }
        }
    }

    Item {
        id: zoomed_image_container

        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: top_menu.bottom
        anchors.bottom: bottom_switcher.top

        opacity: 0

        Rectangle {
            anchors.fill: parent
            opacity: 0.8
            color: "black"
        }

        MouseArea {
            anchors.fill: parent
        }

        SmartImage {
            id: zoomed_image
            width: parent.width
            height: parent.height
            resizeMode: TvnImageController.ScaleAndRotateToPreferredSize
            source: gallery_model.currentImage

            PushButton {
                x: parent.imageX + 10
                y: parent.imageY + 10
                normal_image: "gfx/foto/foto-button_reduce.png"
                pressed_image: "gfx/foto/foto-button_reduce-clicked.png"
                onClicked: {
                    zoomed_image_container.opacity = 0
                }
            }
        }
    }

    function formatEmail(title, desc, url)
    {
        native_utils.sendEmail(title, "Link: " + url);
    }
}
