import QtQuick 1.0
import "InformationView.js" as IV
import com.psiloc 1.1
import "UIConstants.js" as UI

Page {
    id: root
    clip: true
    orientationLock: PageOrientation.LockPortrait

    property int category : IV.OID.Najwazniejsze

    signal newsClicked(int oid, int category, string title)

    function fullReload()
    {
        root_model.reload()
    }

    InformationViewDropDownMenu {
        id: drop_menu
        onCategoryClicked: {
            console.log("Category clicked " + category)
            if(category != root.category)
            {
                root.category = category
            }
        }
    }

    top_category: "INFORMACJE"
    bottom_category: IV.nazwaKategorii(category)
    onReloadClicked: { fullReload() }
    onMenuClicked: { drop_menu.open(category) }
    tab_index: 0

    InformationViewModel {
        id: root_model
        category: root.category
        onStatusChanged: {
            if(status == CategoryBasedModel.Ready || status == CategoryBasedModel.Error) {
                app_root.appStartupComplete()
            }
        }
    }

    ListView {
        id: lv
        anchors.fill: parent
        cacheBuffer: 100
        model: root_model
        header: Item {
            width: root.width
            height: 32

            Text {
                font.pixelSize: 15
                color: "gray"
                text: root_model.lastUpdatedString
                anchors.fill: parent
                anchors.rightMargin: 20
                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter
            }
        }

        delegate: Item {
            id: the_item
            width: root.width
            height: skipThis ? 0 : theLoader.height
            clip: true

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    console.debug("item clicked: "+index)
                    lv.currentIndex = index
                    root.newsClicked(oid, root.category, tytul)
                }
            }

            Image {
                source: (lv.currentIndex == index) ? "gfx/infolist/information_list-item-bg_selected.png" : "gfx/infolist/information_list-item-bg.png"
                anchors.fill: parent
                fillMode: Image.TileHorizontally
            }

            Image {
                source: "gfx/infolist/information_list-item_divider.png"
                anchors.left: parent.left
                anchors.right: parent.right
                anchors.bottom: parent.bottom
            }

            Component {
                id: pierwszy_komponent
                Column {
                    width: the_item.width
                    spacing: 10                  

                    LandscapeImageWithLoader {
                        id: glowny_obrazek                        
                        source: obrazLandscape
                        width: the_item.width
                    }

                    Item {
                        id: glowny_wewnatrz
                        height: opis_glownego_obrazka.height + glowna_strzalka.sourceSize.height
                        width: the_item.width

                        Text {
                            id: opis_glownego_obrazka
                            anchors.left: parent.left
                            anchors.right: glowna_strzalka.left
                            anchors.leftMargin: 10
                            anchors.rightMargin: 10
                            anchors.top: parent.top
                            wrapMode: Text.WordWrap
                            color: "black"
                            font.weight: Font.Bold
                            text: tytul
                            horizontalAlignment: Text.AlignHCenter
                            verticalAlignment: Text.AlignVCenter
                            font.pixelSize: 20
                        }

                        Image {
                            id: glowna_strzalka
                            source: "gfx/infolist/information_list-item-arrow.png"
                            anchors.right: parent.right
                            anchors.verticalCenter: parent.verticalCenter                            
                            anchors.rightMargin: 10
                        }
                    }
                }
            }

            Component {
                id: kolejny_komponent
                Item {
                    id: kolejny_wewnatrz
                    width: the_item.width
                    height: Math.max(maly_obrazek.height, druga_kolumna.height) + 15

                    SmartImage {
                        id: maly_obrazek
                        source: obraz
                        width: 104
                        height: 75
                        anchors.verticalCenter: parent.verticalCenter
                        resizeMode: TvnImageController.DontScale
                    }

                    Column {
                        id: druga_kolumna
                        anchors.left: maly_obrazek.right
                        anchors.right: kolejna_strzalka.left
                        anchors.rightMargin: 17
                        anchors.leftMargin: 10                       
                        y: 10

                        Text {
                            id: drugi_czas
                            text: czas.length > 0 ? czas : data_str
                            color: "gray"
                            font.pixelSize: 15
                            font.weight: Font.DemiBold
                            y: 24
                        }

                        Text {
                            text: tytul
                            color: "#3ba5cf"
                            font.pixelSize: 15
                            font.weight: Font.DemiBold
                            wrapMode: Text.WordWrap
                            anchors.topMargin: 5
                            anchors.rightMargin: 5
                            anchors.left: parent.left
                            anchors.right: parent.right
                        }
                    }

                    Image {
                        id: kolejna_strzalka
                        source: "gfx/infolist/information_list-item-arrow.png"
                        anchors.right: parent.right
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.rightMargin: 10
                    }
                }
            }

            Loader {
                id: theLoader
                sourceComponent: (index == 0 && root.category == 1) ? pierwszy_komponent : kolejny_komponent
            }
        }
    }

    WaitBar {
        anchors.bottom: lv.bottom
        anchors.left: lv.left
        anchors.right: lv.right
        on: root_model.status == CategoryBasedModel.Loading
    }

    ScrollBar {
        id: scroll_bar
        anchors { right: lv.right; top: lv.top; bottom: lv.bottom; }
        width: 8
        scrollArea: lv
    }
}
