import QtQuick 1.0
import QtMultimediaKit 1.1
import QtMobility.systeminfo 1.1
import com.psiloc 1.1
import "."

Page {
    id: video_player_root
    clip: true

    header_visible : false
    footer_visible : false
    top_category : ""
    bottom_category : ""
    tab_index : 1
    orientationLock: PageOrientation.LockLandscape

    ScreenSaver {
        id: screen_saver
        screenSaverInhibited: video.playing
    }

    property bool app_active : Qt.application.active

    onApp_activeChanged: {
        console.log("Active changed to " + app_active)

        if(!app_active) {
            if(video.playing && !video.paused)
            {
                video.pause()
            }
        } else {
            if(video.playing && video.paused)
            {
                video.play()
            }
        }
    }

    Image {
        anchors.fill: parent
        source: "gfx/video/video-bg.png"
    }

    Video {
        id: video
        autoLoad: true
        anchors.fill: parent
        volume: 0.5

        onStatusChanged: {
            console.log("Status is " + status)
            if(status == Video.Loading) {
                loading_bar.state = "Visible"
                time_bar.state = "Visible"
            } else if(status == Video.Loaded) {
                loading_bar.state = ""
                time_bar_hide_timer.start()
                video.play()
            } else if(status == Video.Stalled) {
                loading_bar.state = "Visible"
                time_bar.state = "Visible"
                time_bar_hide_timer.restart()
            } else if(status == Video.EndOfMedia) {
                video.stop()
                video.source = ""
                time_bar.state = ""
                loading_bar.state = ""
                time_bar_hide_timer.stop()
                app_root.goBack()
            } else if(status == Video.InvalidMedia) {
                video.stop()
                video.source = ""
                time_bar.state = ""
                loading_bar.state = ""
                time_bar_hide_timer.stop()
                app_root.goBack()
            } else {
                loading_bar.state = ""
            }
        }
    }

    MouseArea {
        anchors.fill: parent

        onClicked: {
            if(video.status == Video.Buffered)
            {
                if(time_bar.state == "") {
                    time_bar.state = "Visible"
                    time_bar_hide_timer.start()
                } else {
                    time_bar.state = ""
                    time_bar_hide_timer.stop()
                }
            }
        }
    }

    Item {
        id: loading_bar
        anchors.left: parent.left
        anchors.right: parent.right
        height: 32
        y: -height
        opacity: 0

        Rectangle {
            anchors.fill: parent
            color: "black"
            opacity: 0.8
        }

        Text {
            anchors.fill: parent
            font.pixelSize: 18
            text: "Ładowanie ..."
            color: "white"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            elide: Text.ElideRight
        }

        states: [
            State {
                name: "Visible"
                PropertyChanges {
                    target: loading_bar
                    opacity: 1
                    y: 0
                }
            }
        ]

        transitions: [
            Transition {
                from: ""
                to: "Visible"
                NumberAnimation { target: loading_bar; property: "y"; duration: 300 }
            },
            Transition {
                from: "Visible"
                to: ""
                NumberAnimation { target: loading_bar; properties: "opacity,y"; duration: 500 }
            }
        ]
    }

    Timer {
        id: time_bar_hide_timer
        interval: 5000
        repeat: false

        onTriggered: {
            time_bar.state = ""
        }
    }

    Item {
        id: time_bar
        anchors.left: parent.left
        anchors.right: parent.right
        height: 32
        y: parent.height
        opacity: 0

        Rectangle {
            anchors.fill: parent
            color: "black"
            opacity: 0.8
        }

        function formatTimeStr(pos, dur)
        {
            if(dur == 0)
                return native_utils.formatPosition(pos)
            return native_utils.formatPosition(pos) + " / " + native_utils.formatPosition(dur)
        }

        Text {
            id: time_text
            anchors.left: parent.left
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            font.pixelSize: 18
            text: time_bar.formatTimeStr(video.position, video.duration)
            verticalAlignment: Text.AlignVCenter
            anchors.leftMargin: 10
            anchors.rightMargin: 20
            color: "white"
        }

        states: [
            State {
                name: "Visible"
                PropertyChanges {
                    target: time_bar
                    opacity: 1
                    y: parent.height - time_bar.height
                }
            }
        ]

        transitions: [
            Transition {
                from: ""
                to: "Visible"
                NumberAnimation { target: time_bar; property: "y"; duration: 300 }
            },
            Transition {
                from: "Visible"
                to: ""
                NumberAnimation { target: time_bar; properties: "opacity,y"; duration: 500 }
            }
        ]
    }

    PushButton {
        id: go_back_button
        anchors.left: parent.left
        anchors.top: parent.top
        anchors.margins: 10
        normal_image: "gfx/header/header-button_back.png"
        pressed_image: "gfx/header/header-button_back-clicked.png"
        onClicked: {
            video.stop()
            video.source = ""
            app_root.goBack()
        }
    }

    function goBack()
    {
        video.stop()
        video.source = ""
        app_root.goBack()
    }

    function openAndPlay(url)
    {
        video.source = url
    }
}
