import QtQuick 1.0
import com.psiloc 1.1
import "VideoView.js" as VV

Page {
    id: root
    clip: true
    orientationLock: PageOrientation.LockPortrait

    property int category : 222 //najnowsze

    top_category : "WIDEO"
    bottom_category : VV.categoryName(root.category)
    tab_index : 1
    onReloadClicked: { the_model.reload() }
    onMenuClicked: { drop_menu.open(root.category) }

    Image {
        anchors.fill: parent
        source: "gfx/video/video-bg.png"
    }

    VideoViewDropDownMenu {
        id: drop_menu
        onCategoryClicked: {
            if(category != root.category) {
                root.category = category
            }
        }
    }

    ListView {
        id: lv
        anchors.fill: parent
        anchors.leftMargin: 10
        anchors.rightMargin: 10
        cacheBuffer: 100
        model: VideoModel {
            id: the_model
            category: root.category
        }
        delegate: Item {
            width: lv.width
            height: bg_image.height + 20
            id: video_container

            BorderImage {
                y: 10
                id: bg_image
                width: lv.width
//                height: sourceSize.width == 0 ? sourceSize.height : (width * (sourceSize.height / sourceSize.width))
                anchors.horizontalCenter: parent.horizontalCenter
                source: "gfx/video/video-item-bg.png"
                border.left: 11
                border.right: 11
                border.top: 11
                border.bottom: 11
            }

            SmartImage {
                id: video_image
                anchors.fill: bg_image
                anchors.topMargin: 17
                anchors.bottomMargin: 17
                anchors.leftMargin: 5
                anchors.rightMargin: 5
                source: img_url
                smooth: true
            }

            Image {
                id: bottom_field_image
                source: "gfx/video/video-item_title-bg.png"
                anchors.bottom: video_image.bottom
                anchors.left: video_image.left
                anchors.right: video_image.right
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    if(video_container.state == "")
                        video_container.state = "DISPLAY_INFO"
                    else
                        video_container.state = ""
                }
            }

            Text {
                font.pixelSize: 18
                color: "white"
                elide: Text.ElideRight
                anchors.fill: bottom_field_image
                horizontalAlignment: Text.AlignLeft
                verticalAlignment: Text.AlignVCenter
                text: tytul
            }

            PushButton {
                id: play_button_center
                anchors.centerIn: video_image
                normal_image: "gfx/video/video-button_play.png"
                pressed_image: "gfx/video/video-button_play-clicked.png"
                onClicked: {
                    if(native_utils.useRtspForVideo())
                        app_root.playVideo(rtsp);
                    else
                        app_root.playVideo(url)
                }
            }

            Item {
                id: info_box
                anchors.left: video_image.left
                anchors.right: video_image.right
                anchors.bottom: bottom_field_image.top
                anchors.top: video_image.top
                opacity: 0

                Image {
                    source: "gfx/video/video-item_back-bg.png"
                    anchors.fill: parent
                }

                PushButton {
                    id: play_button_center_2
                    anchors.right: parent.right
                    anchors.bottom: parent.bottom
                    anchors.margins: 5
                    normal_image: "gfx/video/video-button_play.png"
                    pressed_image: "gfx/video/video-button_play-clicked.png"
                    onClicked: {
                        if(native_utils.useRtspForVideo())
                            app_root.playVideo(rtsp);
                        else
                            app_root.playVideo(url)
                    }
                }

                PushButton {
                    id: mail_button
                    anchors.right: parent.right
                    anchors.top: parent.top
                    anchors.margins: 5
                    normal_image: "gfx/video/video-button_send.png"
                    pressed_image: "gfx/video/video-button_send-clicked.png"

                    onClicked: {
                        formatEmail(tytul,
                                    /*details_model.description*/opis,
                                    url)
                    }
                }

                Text {
                    id: descr_text
                    anchors.left: parent.left
                    anchors.right: play_button_center_2.left
                    anchors.top: parent.top
                    anchors.bottom: parent.bottom
                    anchors.margins: 5
                    wrapMode: Text.WordWrap
                    color: "black"
                    font.pixelSize: 15
                    text: opis //details_model.description
                    clip: true
                    textFormat: Text.RichText
                    elide: Text.ElideRight

                }

//                WaitBar {
//                    id: details_load_wait
//                    anchors.fill: descr_text
//                    on: details_model.status == VideoDetailsModel.Loading
//                }

//                VideoDetailsModel {
//                    id: details_model
//                }
            }

            states: [
                State {
                    name: "DISPLAY_INFO"
                    PropertyChanges {
                        target: info_box
                        opacity: 1
                    }
                    PropertyChanges {
                        target: play_button_center
                        opacity: 0
                    }
//                    PropertyChanges {
//                        target: details_model
//                        movieId: oid
//                    }
                }
            ]

            transitions: [
                Transition {
                    from: "*"
                    to: "*"
                    NumberAnimation { target: info_box; property: "opacity"; duration: 400 }
                }
            ]
        }
    }

    ScrollBar {
        id: scroll_bar
        anchors { right: parent.right; top: parent.top; bottom: parent.bottom; }
        width: 8
        scrollArea: lv
    }

    WaitBar {
        anchors.bottom: lv.bottom
        anchors.left: lv.left
        anchors.right: lv.right
        on: the_model.status == VideoModel.Loading
    }

    function formatEmail(title, desc, url)
    {
        native_utils.sendEmail(title, "Obejrzyj: " + url);
    }
}
